// Copyright 2024 Martin Riedl
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
// 	http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

package gomp4

type AVCSampleEntry struct {
	*VisualSampleEntry
	// TODO: some more
}

// BoxTypeAVCSampleEntry1 AVC Sample Entry Box
const BoxTypeAVCSampleEntry1 = "avc1"

// BoxTypeAVCSampleEntry3 AVC Sample Entry Box
const BoxTypeAVCSampleEntry3 = "avc3"

func init() {
	BoxDefinitions = append(BoxDefinitions, BoxDefinition{
		Type:        BoxTypeAVCSampleEntry1,
		ParentTypes: []string{BoxTypeSampleDescription},
		Parser:      ParseAVCSampleEntry,
	}, BoxDefinition{
		Type:        BoxTypeAVCSampleEntry3,
		ParentTypes: []string{BoxTypeSampleDescription},
		Parser:      ParseAVCSampleEntry,
	})
}

// ParseAVCSampleEntry creates a new AVC sample entry box struct based on bytes
func ParseAVCSampleEntry(parser *Parser, filePosition uint64, headerSize uint32, content []byte) (any, error) {
	sampleEntry, position := ParseVisualSampleEntry(filePosition, headerSize, content)
	box := &AVCSampleEntry{
		VisualSampleEntry: sampleEntry,
	}

	// TODO: parse other fields
	_ = position

	return box, nil
}
